# README Citation

To cite the OSS package or the documentation, see the [CITATION.cff](../../CITATION.cff).

Below is the citation data in other formats.

### BibTex

```
% version included:
@misc{ossParaMorse010,
  author       = {Peter Toshev},
  title        = {Para{Morse}},
  year         = {2025},
  url          = {https://github.com/petertoshev/paramorse/releases/tag/0.1.0},
  howpublished = {\url{https://github.com/petertoshev/paramorse/releases/tag/0.1.0}},
  note         = {Version 0.1.0, open-source software},
}

% version not included:
@misc{ossParaMorse,
  author       = {Peter Toshev},
  title        = {Para{Morse}},
  year         = {2025},
  url          = {https://github.com/petertoshev/paramorse},
  howpublished = {\url{https://github.com/petertoshev/paramorse}},
  note         = {Open-source software},
}
```

### BibLaTex

```
% version included:
@software{ossParaMorse010,
  author   = {Toshev, Peter},
  title    = {Para{Morse}},
  date     = {2025},
  version  = {0.1.0},
  url      = {https://github.com/petertoshev/paramorse/releases/tag/0.1.0},
}

% version not included:
@software{ossParaMorse,
  author   = {Toshev, Peter},
  title    = {Para{Morse}},
  date     = {2025},
  url      = {https://github.com/petertoshev/paramorse},
}

```

### Example bibliography entry

Reference in IEEE style:  

P. Toshev. *ParaMorse*. (2025). [Software]. Available: https://github.com/petertoshev/paramorse.
